# pymill [![Build Status](https://travis-ci.org/Danielhiversen/pymill.svg?branch=master)](https://travis-ci.org/Danielhiversen/pymill)

Python3 library for Mill heater.

Control Mill heaters and get measured temperatures.

[Buy me a coffee :)](http://paypal.me/dahoiv)



## Install
```
pip3 install millheater
```



The library is used as part of Home Assistant: https://github.com/home-assistant/core/blob/dev/homeassistant/components/mill/climate.py
